CutResult

Struct CutResult 

pub struct CutResult { /* private fields */ }
Result of cutting a selection together with the resulting edit outcome.

Implementations

Source

impl CutResult

pub fn new(text: String, edit: EditResult) -> Self

Creates a cut result.

pub fn text(&self) -> &str

Returns the cut text.

pub fn into_text(self) -> String

Consumes the result and returns the owned cut text.

pub const fn edit(&self) -> EditResult

Returns the underlying edit result.

pub const fn changed(&self) -> bool

Returns true when the document changed.

pub const fn cursor(&self) -> TextPosition

Returns the resulting cursor position.