BackgroundActivity

Enum BackgroundActivity 

pub enum BackgroundActivity {
    Idle,
    Loading(FileProgress),
    Saving(FileProgress),
}
Current background activity of a DocumentSession or EditorTab.

Variants



Idle



Loading(FileProgress)



Saving(FileProgress)

Implementations

Source

impl BackgroundActivity

pub fn is_idle(&self) -> bool

Returns true when no background work is active.

pub fn loading_state(&self) -> Option<&FileProgress>

Returns the current loading progress when a background open is active.

pub fn loading_phase(&self) -> Option<LoadPhase>

Returns the current loading phase when a background open is active.

pub fn save_state(&self) -> Option<&FileProgress>

Returns the current save progress when a background save is active.

pub fn progress(&self) -> Option<&FileProgress>

Returns whichever file-backed progress is currently active.