pub enum BackgroundActivity {
Idle,
Loading(FileProgress),
Saving(FileProgress),
}Expand description
Current background activity of a DocumentSession or EditorTab.
Variants
Implementations
Sourceimpl BackgroundActivity
impl BackgroundActivity
Sourcepub fn loading_state(&self) -> Option<&FileProgress>
pub fn loading_state(&self) -> Option<&FileProgress>
Returns the current loading progress when a background open is active.
Sourcepub fn loading_phase(&self) -> Option<LoadPhase>
pub fn loading_phase(&self) -> Option<LoadPhase>
Returns the current loading phase when a background open is active.
Sourcepub fn save_state(&self) -> Option<&FileProgress>
pub fn save_state(&self) -> Option<&FileProgress>
Returns the current save progress when a background save is active.
Sourcepub fn progress(&self) -> Option<&FileProgress>
pub fn progress(&self) -> Option<&FileProgress>
Returns whichever file-backed progress is currently active.